@@ -1,5 +1,8 @@
 package Gen::Test::Rinci::FuncResult;
 
+our $DATE = '2017-07-11'; # DATE
+our $VERSION = '0.06'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
@@ -14,8 +17,6 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(gen_test_func);
 
-our $VERSION = '0.04'; # VERSION
-
 our %SPEC;
 
 $SPEC{gen_test_func} = {
@@ -194,7 +195,7 @@ sub gen_test_func {
 }
 
 1;
-# ABSTRACT: Generate function to test a function
+# ABSTRACT: Generate a test function for a function
 
 __END__
 
@@ -204,11 +205,11 @@ __END__
 
 =head1 NAME
 
-Gen::Test::Rinci::FuncResult - Generate function to test a function
+Gen::Test::Rinci::FuncResult - Generate a test function for a function
 
 =head1 VERSION
 
-This document describes version 0.04 of Gen::Test::Rinci::FuncResult (from Perl distribution Gen-Test-Rinci-FuncResult), released on 2014-05-17.
+This document describes version 0.06 of Gen::Test::Rinci::FuncResult (from Perl distribution Gen-Test-Rinci-FuncResult), released on 2017-07-11.
 
 =head1 SYNOPSIS
 
@@ -234,7 +235,11 @@ This document describes version 0.04 of Gen::Test::Rinci::FuncResult (from Perl
 =head1 FUNCTIONS
 
 
-=head2 gen_test_func(%args) -> [status, msg, result, meta]
+=head2 gen_test_func
+
+Usage:
+
+ gen_test_func(%args) -> [status, msg, result, meta]
 
 Generate a test function for a function.
 
@@ -251,63 +256,35 @@ B will accept the following arguments:
 
 =over
 
-=item *
+=item * name (str)
 
-name (str)
+Name of the test. Will default to "T (ARGS...)" to show the name of the target
+function and the arguments that it is called with.
 
-  Name of the test. Will default to "T (ARGS...)" to show the name of the target
-  function and the arguments that it is called with.
+=item * args (hash or array)
 
+Argument to feed to function T.
 
+=item * dies (bool, default => 0)
 
-=item *
+Whether function T should die when run. If set to 1, further tests will not be
+done except the test that function dies.
 
-args (hash or array)
+=item * status (int, default => 200)
 
-  Argument to feed to function T.
+Will test the result's status code.
 
+=item * result (any)
 
+If specified, will test the actual result of the function.
 
-=item *
+=item * run (code)
 
-dies (bool, default => 0)
-
-  Whether function T should die when run. If set to 1, further tests will not be
-  done except the test that function dies.
-
-
-
-=item *
-
-status (int, default => 200)
-
-  Will test the result's status code.
-
-
-
-=item *
-
-result (any)
-
-  If specified, will test the actual result of the function.
-
-
-
-=item *
-
-run (code)
-
-  Instead of running function T with C<args>, will execute this code instead.
-
-
-
-=item *
-
-posttest (code)
-
-  Run this code for additional tests.
+Instead of running function T with C<args>, will execute this code instead.
 
+=item * posttest (code)
 
+Run this code for additional tests.
 
 =back
 
@@ -315,13 +292,12 @@ Todo:
 
 =over
 
-=item *
-
-Handle function with C<result_naked> => 1.
-
+=item * Handle function with C<result_naked> => 1.
 
 =back
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -350,8 +326,6 @@ Relevant only when installing the function.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -361,19 +335,17 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
+Return value:  (any)
+
 =head1 FAQ
 
-=head1 SEE ALSO
-
-L<Rinci>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Gen-Test-Rinci-FuncResult>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Gen-Test-Rinci-FuncResult>.
+Source repository is at L<https://github.com/perlancar/perl-Gen-Test-Rinci-FuncResult>.
 
 =head1 BUGS
 
@@ -383,13 +355,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Rinci>
+
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2017, 2015, 2014, 2013 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
